@@ -1,3 +1,9 @@
+/*******************************************************************************/
+// Copyright 2017-2018 Gabriele Valentini, Douglas G. Moore. All rights reserved.
+// Use of this source code is governed by a MIT license that can be found in the
+// LICENSE file.
+/*******************************************************************************/
+#include <stdlib.h>
 #include "inform/integration.h"
 
 void r_integration_evidence_(int *series, int *l, int *n, int *b,
@@ -11,7 +17,7 @@ void r_integration_evidence_(int *series, int *l, int *n, int *b,
 void r_integration_evidence_parts_(int *series, int *l, int *n, int *b,
 				   int *parts, int *nparts, double *evidence, int *err) {
   inform_error ierr = INFORM_SUCCESS;
-  size_t st_parts[*l];
+  size_t *st_parts = malloc((*l) * sizeof(size_t));
 
   for (size_t i = 0; i < *l; ++i) {
     st_parts[i] = parts[i];
@@ -19,5 +25,6 @@ void r_integration_evidence_parts_(int *series, int *l, int *n, int *b,
 
   inform_integration_evidence_part(series, *l, *n, b, st_parts, *nparts, evidence, &ierr);
   *err = ierr;
+  free(st_parts);
 }
 
